==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/memberlist/languages/de/default.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2008 
 * @author     Leo Feyer 
 * @package    Language
 * @license    LGPL 
 * @filesource
 */


/**
 * Miscellaneous
 */
$GLOBALS['TL_LANG']['MSC']['subject']       = 'Betreff';
$GLOBALS['TL_LANG']['MSC']['message']       = 'Nachricht';
$GLOBALS['TL_LANG']['MSC']['sendMessage']   = 'E-Mail senden';
$GLOBALS['TL_LANG']['MSC']['messageSent']   = 'Ihre Nachricht wurde gesendet.';
$GLOBALS['TL_LANG']['MSC']['publicProfile'] = 'Öffenliches Profil von %s';
$GLOBALS['TL_LANG']['MSC']['noPublicInfo']  = 'Kein öffentliches Profil vorhanden.';
$GLOBALS['TL_LANG']['MSC']['sendEmail']     = 'E-Mail senden';
$GLOBALS['TL_LANG']['MSC']['loginToSend']   = 'Sie müssen sich anmelden, um E-Mails zu versenden.';
$GLOBALS['TL_LANG']['MSC']['emailDisabled'] = 'Der Benutzer hat E-Mails deaktiviert.';

?>

==> typolight-2.6.3.tar.gz: typolight-2.6.3/system/modules/memberlist/languages/de/default.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2008 
 * @author     Leo Feyer 
 * @package    Language
 * @license    LGPL 
 * @filesource
 */


/**
 * Miscellaneous
 */
$GLOBALS['TL_LANG']['MSC']['subject']       = 'Betreff';
$GLOBALS['TL_LANG']['MSC']['message']       = 'Nachricht';
$GLOBALS['TL_LANG']['MSC']['sendMessage']   = 'E-Mail senden';
$GLOBALS['TL_LANG']['MSC']['messageSent']   = 'Ihre Nachricht wurde gesendet.';
$GLOBALS['TL_LANG']['MSC']['publicProfile'] = 'Öffentliches Profil von %s';
$GLOBALS['TL_LANG']['MSC']['noPublicInfo']  = 'Kein öffentliches Profil vorhanden.';
$GLOBALS['TL_LANG']['MSC']['sendEmail']     = 'E-Mail senden';
$GLOBALS['TL_LANG']['MSC']['loginToSend']   = 'Sie müssen sich anmelden, um E-Mails zu versenden.';
$GLOBALS['TL_LANG']['MSC']['emailDisabled'] = 'Der Benutzer hat E-Mails deaktiviert.';

?>
